@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.019-3-g1be444e
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.020-3-gb3746e0
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -92,6 +92,9 @@ sub register_prereqs
 {
     my $self = shift;
 
+    # newer dzil renders META.json in ascii mode
+    return if eval { Dist::Zilla->VERSION('5.045'); 1 };
+
     return if none { /[^[:ascii:]]/ } @{ $self->_contributors };
 
     my $prereqs = $self->zilla->prereqs;
@@ -259,7 +262,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
